@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -48,10 +48,8 @@
 /*
  * include build configuration flags
  */
-#ifndef NO_CONFIG_HEADER
 #include "scip/config.h"
 #include "scip/scip_export.h"
-#endif
 
 /*
  * GNU COMPILER VERSION define
@@ -104,18 +102,16 @@
 /*
  * Add some macros for differing functions on Windows
  */
-#if defined(_WIN32) || defined(_WIN64)
-
+#ifdef _WIN32
 #define strcasecmp _stricmp
 #define strncasecmp _strnicmp
-#define getcwd _getcwd
 #endif
 
 /*
- * Define the marco SCIP_EXPORT if it is not included from the generated header
+ * Define the macro SCIP_EXPORT if it is not included from the generated header
  */
 #ifndef SCIP_EXPORT
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 #define SCIP_EXPORT __declspec(dllexport)
 #elif defined(__GNUC__) && __GNUC__ >= 4
 #define SCIP_EXPORT __attribute__((__visibility__("default")))
@@ -134,20 +130,10 @@
 #endif
 
 
-
-#include "scip/type_retcode.h"
-#include "scip/type_message.h"
-#include "scip/pub_message.h"
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-
-#define SCIP_VERSION                810 /**< SCIP version number (multiplied by 100 to get integer number) */
-#define SCIP_SUBVERSION               0 /**< SCIP sub version number */
-#define SCIP_APIVERSION             104 /**< SCIP API version number */
-#define SCIP_COPYRIGHT   "Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)"
+#define SCIP_VERSION     (100*SCIP_VERSION_MAJOR + 10*SCIP_VERSION_MINOR + SCIP_VERSION_PATCH) /**< SCIP version number (multiplied by 100 to get integer number) */
+#define SCIP_SUBVERSION  SCIP_VERSION_SUB  /**< SCIP sub version number */
+#define SCIP_APIVERSION  SCIP_VERSION_API  /**< SCIP API version number */
+#define SCIP_COPYRIGHT   "Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)"
 
 
 /*
@@ -172,7 +158,7 @@ extern "C" {
 #define SCIP_LONGINT_MAX          LLONG_MAX
 #define SCIP_LONGINT_MIN          LLONG_MIN
 #ifndef SCIP_LONGINT_FORMAT
-#if defined(_WIN32) || defined(_WIN64)
+#ifdef _WIN32
 #define SCIP_LONGINT_FORMAT           "I64d"
 #else
 #define SCIP_LONGINT_FORMAT           "lld"
@@ -199,7 +185,7 @@ extern "C" {
 #define SCIP_DEFAULT_BOUNDSTREPS       0.05  /**< default minimal relative improve for strengthening bounds */
 #define SCIP_DEFAULT_PSEUDOCOSTEPS    1e-01  /**< default minimal variable distance value to use for pseudo cost updates */
 #define SCIP_DEFAULT_PSEUDOCOSTDELTA  1e-04  /**< default minimal objective distance value to use for pseudo cost updates */
-#define SCIP_DEFAULT_RECOMPFAC        1e+07  /**< default minimal decrease factor that causes the recomputation of a value (e.g., pseudo objective) instead of an update */
+#define SCIP_DEFAULT_RECOMPFAC        1e+06  /**< default minimal decrease factor that causes the recomputation of a value (e.g., pseudo objective) instead of an update */
 #define SCIP_DEFAULT_HUGEVAL          1e+15  /**< values larger than this are considered huge and should be handled separately (e.g., in activity computation) */
 #define SCIP_MAXEPSILON               1e-03  /**< maximum value for any numerical epsilon */
 #define SCIP_MINEPSILON               1e-20  /**< minimum value for any numerical epsilon */
@@ -225,12 +211,11 @@ extern "C" {
 
 #ifndef SQR
 #define SQR(x)        ((x)*(x))
-#define SQRT(x)       (sqrt(x))
 #endif
 
 /* platform-dependent specification of the log1p, which is numerically more stable around x = 0.0 */
 #ifndef LOG1P
-#if defined(_WIN32) || defined(_WIN64)
+#ifdef _WIN32
 #define LOG1P(x) (log(1.0+x))
 #else
 #define LOG1P(x) (log1p(x))
@@ -246,7 +231,7 @@ extern "C" {
 #endif
 
 #ifndef ABS
-#define ABS(x)        ((x) >= 0 ? (x) : -(x))
+#define ABS(x)    ((x) >= 0 ? (x) : -(x))
 #endif
 
 #ifndef MAX
@@ -327,7 +312,7 @@ extern "C" {
  * Tree settings
  */
 
-#define SCIP_MAXTREEDEPTH             65534  /**< maximal allowed depth of the branch-and-bound tree */
+#define SCIP_MAXTREEDEPTH     1073741822 /**< maximal allowed depth of the branch-and-bound tree */
 
 /*
  * Probing scoring settings
@@ -455,8 +440,4 @@ extern "C" {
 #endif
 #endif
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif
