@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -386,6 +386,14 @@ SCIP_RETCODE SCIPsetSetStringParam(
    const char*           value               /**< new value of the parameter */
    );
 
+/** changes the value of an existing parameter */
+SCIP_RETCODE SCIPsetSetParam(
+   SCIP_SET*             set,                /**< global SCIP settings */
+   SCIP_MESSAGEHDLR*     messagehdlr,        /**< message handler */
+   const char*           name,               /**< name of the parameter */
+   const char*           value               /**< new value of the parameter as string */
+   );
+
 /** reads parameters from a file */
 SCIP_RETCODE SCIPsetReadParams(
    SCIP_SET*             set,                /**< global SCIP settings */
@@ -1036,6 +1044,12 @@ int SCIPsetGetPriceMaxvars(
    SCIP_Bool             root                /**< are we at the root node? */
    );
 
+/** returns factor for the maximal number of cuts generated per round */
+SCIP_Real SCIPsetGetSepaMaxcutsGenFactor(
+   SCIP_SET*             set,                /**< global SCIP settings */
+   SCIP_Bool             root                /**< are we at the root node? */
+   );
+
 /** returns the maximal number of cuts separated per round */
 int SCIPsetGetSepaMaxcuts(
    SCIP_SET*             set,                /**< global SCIP settings */
