@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -62,6 +62,7 @@
 #include "scip/type_concsolver.h"
 #include "scip/type_benders.h"
 #include "scip/type_expr.h"
+#include "scip/type_message.h"
 #include "scip/debug.h"
 
 #ifdef __cplusplus
@@ -308,18 +309,19 @@ struct SCIP_Set
    SCIP_Real             limit_gap;          /**< solving stops, if the given gap is reached */
    SCIP_Real             limit_absgap;       /**< solving stops, if the absolute difference between primal and dual bound
                                               *   reaches this value */
+   SCIP_Real             limit_primal;       /**< solving stops, if primal bound is at least as good as given value */
+   SCIP_Real             limit_dual;         /**< solving stops, if dual bound is at least as good as given value */
    SCIP_Longint          limit_nodes;        /**< maximal number of nodes to process (-1: no limit) */
    SCIP_Longint          limit_totalnodes;   /**< maximal number of total nodes (incl. restarts) to process (-1: no limit) */
    SCIP_Longint          limit_stallnodes;   /**< solving stops, if the given number of nodes was processed since the
                                               *   last improvement of the primal solution value (-1: no limit) */
-   int                   limit_solutions;    /**< solving stops, if the given number of solutions were found (-1: no limit) */
+   int                   limit_solutions;    /**< solving stops, if the given number of solutions were found; this limit is first checked in presolving (-1: no limit) */
    int                   limit_bestsol;      /**< solving stops, if the given number of solution improvements were found
                                               *   (-1: no limit) */
    int                   limit_maxsol;       /**< maximal number of solutions to store in the solution storage */
    int                   limit_maxorigsol;   /**< maximal number of solutions candidates to store in the solution storage of the original problem */
    int                   limit_restarts;     /**< solving stops, if the given number of restarts was triggered (-1: no limit) */
-   int                   limit_autorestartnodes;/**< nodes to trigger automatic restart */
-
+   int                   limit_autorestartnodes; /**< nodes to trigger automatic restart */
    SCIP_Bool             istimelimitfinite;  /**< is the time limit finite */
 
    /* LP settings */
@@ -341,7 +343,7 @@ struct SCIP_Set
                                               *   freed at end of diving? */
    int                   lp_colagelimit;     /**< maximum age a column can reach before it is deleted from the SCIP_LP
                                               *   (-1: don't delete columns due to aging) */
-   int                   lp_rowagelimit;     /**< maximum age a row can reach before it is deleted from the LP 
+   int                   lp_rowagelimit;     /**< maximum age a row can reach before it is deleted from the LP
                                               *   (-1: don't delete rows due to aging) */
    SCIP_Bool             lp_cleanupcols;     /**< should new non-basic columns be removed after LP solving? */
    SCIP_Bool             lp_cleanupcolsroot; /**< should new non-basic columns be removed after root LP solving? */
@@ -512,7 +514,7 @@ struct SCIP_Set
    SCIP_Bool             reopt_commontimelimit;/**< time limit over all reoptimization rounds? */
    SCIP_Bool             reopt_enable;       /**< enable reoptimization */
    SCIP_Bool             reopt_reducetofrontier; /**< delete stored nodes which were not reoptimized */
-   SCIP_Bool             reopt_saveconsprop; /**< save constraint propagations */
+   SCIP_Bool             reopt_saveprop;     /**< save constraint and propagator propagations */
    SCIP_Bool             reopt_sbinit;       /**< try to fix variables before reoptimizing by probing like strong
                                               *   branching
                                               */
@@ -561,6 +563,10 @@ struct SCIP_Set
                                               *   or integrality improvement (-1: no additional restriction) */
    int                   sepa_maxstallroundsroot;/**< maximal number of consecutive separation rounds without objective
                                               *   or integrality improvement (-1: no additional restriction) */
+   SCIP_Real             sepa_maxcutsgenfactor; /**< factor w.r.t. maxcuts for maximal number of cuts generated per
+                                                 * separation round (-1.0: no limit, >= 0.0: valid finite limit) */
+   SCIP_Real             sepa_maxcutsrootgenfactor; /**< factor w.r.t. maxcutsroot for maximal number of generated cuts
+                                                     * at the root node (-1.0: no limit, >= 0.0: valid finite limit) */
    int                   sepa_maxcuts;       /**< maximal number of cuts separated per separation round */
    int                   sepa_maxcutsroot;   /**< maximal number of separated cuts at the root node */
    int                   sepa_cutagelimit;   /**< maximum age a cut can reach before it is deleted from the global cut pool */
